Structs
- Json
RpcError - Json
RpcRequest - Json
RpcResponse - Task
- Thread
- Thread
Created Event - Thread
Resumed Event - Thread
Switched Event - Thread
Updated Event - Thread
Waited Event
Enums
Functions
- event_
log_ dir - event_
log_ path - index_
path - send_
request - Connect to the daemon socket, send a JSON-RPC request, return the result.
- socket_
path - Derives a stable socket path from the project root directory. Uses first 8 chars of SHA-256 of the path string, so multiple projects can have daemons running simultaneously.
- tasks_
path - Path to the tasks file for a thread:
tsk/threads/{id}-{slug}/tasks.json - thread_
dir - Thread working directory:
tsk/threads/{id:04}-{slug}/ - threads_
dir - tsk_dir