pub fn socket_path(project_root: &Path) -> PathBuf
Derives a stable socket path from the project root directory. Uses first 8 chars of SHA-256 of the path string, so multiple projects can have daemons running simultaneously.